#!/bin/bash

# Location of smbldap executables
IDEALX="/usr/local/sbin"
SMBLDAP_TOOLS="smbldap-tools-0.9.2"

# Binaries and configuration files
BINARY[0]="smbldap-groupadd"
BINARY[1]="smbldap-groupdel"
BINARY[2]="smbldap-groupmod"
BINARY[3]="smbldap-groupshow"
BINARY[4]="smbldap-passwd"
BINARY[5]="smbldap-populate"
BINARY[6]="smbldap-useradd"
BINARY[7]="smbldap-userdel"
BINARY[8]="smbldap-usermod"
BINARY[9]="smbldap-usershow"
BINARY[10]="smbldap_tools.pm"
CONF[0]="smbldap.conf"
CONF[1]="smbldap_bind.conf"

# The build instructions say to copy the configuration files to
# /etc/smbldap_tools, but smbldap-populate looks here:
CONFLOC[0]="/etc/opt/IDEALX"
CONFLOC[1]="/etc/opt/IDEALX/smbldap-tools"

# Determine if smbldap tools need to be installed
if [ -e "$IDEALX/smbldap-populate" ]; then
    echo "$SMBLDAP_TOOLS already installed"
    exit 0
fi

# Default configuration for CPAN
perl -e shell -MCPAN <<EOF
echo "no" > /dev/tty
EOF

# Install required perl modules
echo "Installing required perl modules"
perl -e shell -MCPAN <<EOF
force install Digest
EOF
perl -e shell -MCPAN <<EOF
force install Digest::SHA1
EOF
perl -e shell -MCPAN <<EOF
force install Convert::ASN1
EOF
perl -e shell -MCPAN <<EOF
force install Authen::SASL
EOF
perl -e shell -MCPAN <<EOF
force install Net::SSLeay
EOF
perl -e shell -MCPAN <<EOF
force install IO::Socket::SSL
EOF
perl -e shell -MCPAN <<EOF
force install XML::SAX::Base
EOF
perl -e shell -MCPAN <<EOF
force install Net::LDAP
EOF
perl -e shell -MCPAN <<EOF
force install Crypt::SmbHash
EOF
perl -e shell -MCPAN <<EOF
force install Unicode::Map8
EOF
perl -e shell -MCPAN <<EOF
force install Unicode::String
EOF
perl -e shell -MCPAN <<EOF
force install Jcode
EOF
perl -e shell -MCPAN <<EOF
force install Unicode::Map
EOF
perl -e shell -MCPAN <<EOF
force install Unicode::MapUTF8
EOF

# Remove stray perl processes
pid=`ps -C "perl -e shell -MCPAN" --no-headers -o pid`
kill -9 $pid

# Download, build, and install the smbldap tools
echo "Downloading $SMBLDAP_TOOLS.tgz"
wget http://www.idealx.com/downloads/$SMBLDAP_TOOLS.tgz
tar -xzf $SMBLDAP_TOOLS.tgz
rm -f $SMBLDAP_TOOLS.tgz
cd $SMBLDAP_TOOLS

# Create the installation directories
echo "Creating installation directories"
mkdir -m 644 ${CONFLOC[0]}
mkdir -m 644 ${CONFLOC[1]}

# Copy the executables
echo "Copying $SMBLDAP_TOOLS executables"
for ((N=0; N<11; N++)); do
    cp ${BINARY[$N]} ${IDEALX}/${BINARY[$N]}
    chmod +x ${IDEALX}/${BINARY[$N]}
done

echo "Copying $SMBLDAP_TOOLS configuration files"
# Copy the configuration files
cp ${CONF[0]} ${CONFLOC[1]}/${CONF[0]}
chmod 644 ${CONFLOC[1]}/${CONF[0]}
cp ${CONF[1]} ${CONFLOC[1]}/${CONF[1]}
chmod 600 ${CONFLOC[1]}/${CONF[1]}

# Delete the source files
echo "Deleting $SMBLDAP_TOOLS source files"
cd ..
rm -rf $SMBLDAP_TOOLS

# Exit
exit 0
