#!/usr/bin/perl

# Copyright(C) 2005, International Business Machines Corporation.  All
# Rights Reserved.

# Usage: undo_config.pl -c <configuration file> -l <logfile>

use lib "../util";
use test_tools;
use Getopt::Std;
my %Options;
my $ok = getopts('c:l:', \%Options);
my $testconf = $Options{c};
if (!$testconf) {
    print "Please enter -c configuration file\n";
    usage();
    exit(1);
}
$logfile = $Options{l};
if (!$logfile) {
    $logfile = "/dev/null";
}
open_logfile;

# Get the configuration options
read_test_conf($testconf);

# Remove the users
delete_users;

# Remove the groups
if ($backend eq "ldapsam") {
    system_logged("smbldap-groupdel sambaadmins");
    system_logged("smbldap-groupdel sambausers");
    system_logged("smbldap-groupdel domadmins");
    system_logged("smbldap-groupdel domusers");
} else {
    system_logged("groupdel sambaadmins");
    system_logged("groupdel sambausers");
    system_logged("groupdel domadmins");
    system_logged("groupdel domusers");
}

# Stop the processes
system_logged("/etc/init.d/smb stop");
system_logged("/etc/init.d/nmb stop");
system_logged("chkconfig smb off");
system_logged("net cache flush");
if ($backend eq "ldapsam") {
    system_logged("/etc/init.d/ldap stop");
    system_logged("rm -f /var/lib/ldap/*");
    system_logged("chkconfig ldap off");
}

# Restore the original configuration files
system_logged("mv -f /etc/samba/smb.conf.orig /etc/samba/smb.conf");
if ($backend eq "ldapsam") {
    # Restore ldap's original configuration
    system_logged("mv -f /etc/ldap.conf.orig /etc/ldap.conf");
    system_logged("mv -f /etc/openldap/ldap.conf.orig /etc/openldap/ldap.conf");
    system_logged("mv -f /etc/openldap/slapd.conf.orig /etc/openldap/slapd.conf");
    system_logged("mv -f /etc/nsswitch.conf.orig /etc/nsswitch.conf");

    # Restore unix root and nobody groups
    if ($ldapsamtrusted eq "yes") {
        system_logged("usermod -g 0 root");
        my $os = get_distro;
        if ($os eq "sles9") {
            system_logged("usermod -g 65533 nobody");
        } else {
            system_logged("usermod -g 99 nobody");
        }
    }
} 

# Remove samba db files
system_logged("rm /etc/samba/*.tdb");
system_logged("rm /var/lib/samba/*.tdb");
system_logged("rm /var/lib/samba/*.dat");
system_logged("rm /usr/private/*.tdb");

# Remove samba log files
system_logged("rm /var/log/samba/*");

# Remove the share directories
my $fsdir;
foreach (@fileshares) {
    $fsdir = $fsdirs{"$_"};
    system_logged("rm -rf $fsdir");
}

# Remove the printer
delete_printer;

# Remove machine accounts
if ($pdc eq "yes") {
    delete_machine_users;
}

# ================
# Usage subroutine
# ================

sub usage {
    print "Usage: $0 -c <configuration file> -l <logfile>\n"
}
